<?php
session_start();

// Simulated company database stored in session
if (!isset($_SESSION["companies"])) {
    $_SESSION["companies"] = [
        ["company_name" => "Tech Innovations Ltd", "company_number" => "12345", "status" => "Active", "phone" => "08012345678", "email" => "info@techinnovations.com"],
        ["company_name" => "Open Innovations Ltd", "company_number" => "12845", "status" => "Active", "phone" => "08123456789", "email" => "contact@openinnovations.com"],
        ["company_name" => "Green Energy Corp", "company_number" => "67890", "status" => "Active", "phone" => "07098765432", "email" => "support@greenenergy.com"],
        ["company_name" => "Blue Ocean Enterprises", "company_number" => "54321", "status" => "Inactive", "phone" => "09087654321", "email" => "sales@blueocean.com"]
    ];
}

$companies = &$_SESSION["companies"];

// Handle Add, Edit, and Delete Actions
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    if (isset($_POST["add"])) {
        $newCompany = [
            "company_name" => $_POST["company_name"],
            "company_number" => $_POST["company_number"],
            "status" => $_POST["status"],
            "phone" => $_POST["phone"],
            "email" => $_POST["email"]
        ];
        $companies[] = $newCompany;
    } elseif (isset($_POST["edit"])) {
        $index = $_POST["index"];
        $companies[$index] = [
            "company_name" => $_POST["company_name"],
            "company_number" => $_POST["company_number"],
            "status" => $_POST["status"],
            "phone" => $_POST["phone"],
            "email" => $_POST["email"]
        ];
    } elseif (isset($_POST["delete"])) {
        $index = $_POST["index"];
        array_splice($companies, $index, 1);
    }
    header("Location: " . $_SERVER["PHP_SELF"]);
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Companies</title>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
</head>
<body class="container mt-5">

<h2 class="mb-4">Company Management</h2>

<!-- Add New Company Form -->
<form method="POST" class="mb-4 border p-3 rounded">
    <h4>Add New Company</h4>
    <div class="mb-2">
        <label>Company Name:</label>
        <input type="text" name="company_name" class="form-control" required>
    </div>
    <div class="mb-2">
        <label>Company Number:</label>
        <input type="text" name="company_number" class="form-control" required>
    </div>
    <div class="mb-2">
        <label>Status:</label>
        <select name="status" class="form-control">
            <option value="Active">Active</option>
            <option value="Inactive">Inactive</option>
        </select>
    </div>
    <div class="mb-2">
        <label>Phone:</label>
        <input type="text" name="phone" class="form-control" required>
    </div>
    <div class="mb-2">
        <label>Email:</label>
        <input type="email" name="email" class="form-control" required>
    </div>
    <button type="submit" name="add" class="btn btn-success mt-2">Add Company</button>
</form>

<!-- Display Companies -->
<table class="table table-bordered">
    <thead class="table-dark">
        <tr>
            <th>#</th>
            <th>Company Name</th>
            <th>Company Number</th>
            <th>Status</th>
            <th>Phone</th>
            <th>Email</th>
            <th>Actions</th>
        </tr>
    </thead>
    <tbody>
        <?php foreach ($companies as $index => $company): ?>
            <tr>
                <td><?= $index + 1 ?></td>
                <td><?= htmlspecialchars($company["company_name"]) ?></td>
                <td><?= htmlspecialchars($company["company_number"]) ?></td>
                <td class="<?= $company["status"] == "Active" ? 'text-success' : 'text-danger' ?>">
                    <?= htmlspecialchars($company["status"]) ?>
                </td>
                <td><?= htmlspecialchars($company["phone"]) ?></td>
                <td><?= htmlspecialchars($company["email"]) ?></td>
                <td>
                    <!-- Edit Button -->
                    <button class="btn btn-primary btn-sm" onclick="editCompany(<?= $index ?>)">Edit</button>

                    <!-- Delete Form -->
                    <form method="POST" style="display:inline;">
                        <input type="hidden" name="index" value="<?= $index ?>">
                        <button type="submit" name="delete" class="btn btn-danger btn-sm">Delete</button>
                    </form>
                </td>
            </tr>
        <?php endforeach; ?>
    </tbody>
</table>

<!-- Edit Company Form (Hidden) -->
<div id="editForm" class="mb-4 border p-3 rounded" style="display: none;">
    <h4>Edit Company</h4>
    <form method="POST">
        <input type="hidden" name="index" id="editIndex">
        <div class="mb-2">
            <label>Company Name:</label>
            <input type="text" name="company_name" id="editCompanyName" class="form-control" required>
        </div>
        <div class="mb-2">
            <label>Company Number:</label>
            <input type="text" name="company_number" id="editCompanyNumber" class="form-control" required>
        </div>
        <div class="mb-2">
            <label>Status:</label>
            <select name="status" id="editStatus" class="form-control">
                <option value="Active">Active</option>
                <option value="Inactive">Inactive</option>
            </select>
        </div>
        <div class="mb-2">
            <label>Phone:</label>
            <input type="text" name="phone" id="editPhone" class="form-control" required>
        </div>
        <div class="mb-2">
            <label>Email:</label>
            <input type="email" name="email" id="editEmail" class="form-control" required>
        </div>
        <button type="submit" name="edit" class="btn btn-warning mt-2">Update Company</button>
    </form>
</div>

<!-- JavaScript to Populate Edit Form -->
<script>
function editCompany(index) {
    const companies = <?= json_encode($companies) ?>;
    const company = companies[index];

    document.getElementById("editIndex").value = index;
    document.getElementById("editCompanyName").value = company.company_name;
    document.getElementById("editCompanyNumber").value = company.company_number;
    document.getElementById("editStatus").value = company.status;
    document.getElementById("editPhone").value = company.phone;
    document.getElementById("editEmail").value = company.email;

    document.getElementById("editForm").style.display = "block";
}
</script>

</body>
</html>
